fn roster_enrolees(
people: &[RosterPerson],
linked: &LinkedAccounts<'_>,
) -> Vec<RosterEnrolee>Expand description
The linked accounts on the roster, each with every enrolment id the registry lists them under.
fn roster_enrolees(
people: &[RosterPerson],
linked: &LinkedAccounts<'_>,
) -> Vec<RosterEnrolee>The linked accounts on the roster, each with every enrolment id the registry lists them under.